# Description

This repo contains common util code using in various python projects across Mosaic

# To Install via source

pip install .

# To install along with all the dependencies

pip install ".[complete]"

# Other versions available

pip install ".[flavours]"

pip install ".[common]"

pip install ".[metrics]"